.. _home:


.. raw:: html

    <br>

.. title:: Home


.. raw:: html

    <center><b>OTP-CR-117/19</b></center>
    <br>

In 2018 i informed the king of the netherlands that what he calls
medicine in his "care" laws are not medicine but poison. Proof of
these medicine being poison were shown to the king, who's (personal)
kabinet wrote back that "the king took note of what i have written".

Using poison makes the care laws used in the netherlands to provide
care to elderly and handicapped, criminals and psychiatric patients
not care laws but genocide laws with which the king is killing groups
of the population by giving them poison instead of medicine in
the "care" they are forced to undergo.

I wrote the prosecutor asking for an arrest of the king (make him
stop), the prosecutor decided to call it a "no basis to proceed".

.. raw:: html

    <br><br>
    <center>
    <b>

It requires a :ref:`basis to prosecute <reconsider>` of the prosecutor
to get the king in his cell and his genocide, thereby, stopped.

.. raw:: html

    </center>
    </b>
    <br>

.. raw:: html

    <center>

.. image:: skull3.png
    :width: 90%
    :target: manual.html

.. raw:: html

    </center>
